==> zio-aws-apigateway_2.13-6.20.42.1-sources.jar: zio/aws/apigateway/model/CreateRestApiResponse.scala <==
package zio.aws.apigateway.model
import zio.aws.apigateway.model.primitives.{NullableInteger, Timestamp}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateRestApiResponse(
    id: Optional[String] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    createdDate: Optional[Timestamp] = Optional.Absent,
    version: Optional[String] = Optional.Absent,
    warnings: Optional[Iterable[String]] = Optional.Absent,
    binaryMediaTypes: Optional[Iterable[String]] = Optional.Absent,
    minimumCompressionSize: Optional[NullableInteger] = Optional.Absent,
    apiKeySource: Optional[zio.aws.apigateway.model.ApiKeySourceType] =
      Optional.Absent,
    endpointConfiguration: Optional[
      zio.aws.apigateway.model.EndpointConfiguration
    ] = Optional.Absent,
    policy: Optional[String] = Optional.Absent,
    tags: Optional[Map[String, String]] = Optional.Absent,
    disableExecuteApiEndpoint: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse = {
    import CreateRestApiResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        createdDate.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdDate)
      .optionallyWith(version.map(value => value: java.lang.String))(_.version)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.warnings)
      .optionallyWith(
        binaryMediaTypes.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.binaryMediaTypes)
      .optionallyWith(minimumCompressionSize.map(value => value: Integer))(
        _.minimumCompressionSize
      )
      .optionallyWith(apiKeySource.map(value => value.unwrap))(_.apiKeySource)
      .optionallyWith(
        endpointConfiguration.map(value => value.buildAwsValue())
      )(_.endpointConfiguration)
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(
        disableExecuteApiEndpoint.map(value => value: java.lang.Boolean)
      )(_.disableExecuteApiEndpoint)
      .build()
  }
  def asReadOnly: zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly =
    zio.aws.apigateway.model.CreateRestApiResponse.wrap(buildAwsValue())
}
object CreateRestApiResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.CreateRestApiResponse =
      zio.aws.apigateway.model.CreateRestApiResponse(
        id.map(value => value),
        name.map(value => value),
        description.map(value => value),
        createdDate.map(value => value),
        version.map(value => value),
        warnings.map(value => value),
        binaryMediaTypes.map(value => value),
        minimumCompressionSize.map(value => value),
        apiKeySource.map(value => value),
        endpointConfiguration.map(value => value.asEditable),
        policy.map(value => value),
        tags.map(value => value),
        disableExecuteApiEndpoint.map(value => value)
      )
    def id: Optional[String]
    def name: Optional[String]
    def description: Optional[String]
    def createdDate: Optional[Timestamp]
    def version: Optional[String]
    def warnings: Optional[List[String]]
    def binaryMediaTypes: Optional[List[String]]
    def minimumCompressionSize: Optional[NullableInteger]
    def apiKeySource: Optional[zio.aws.apigateway.model.ApiKeySourceType]
    def endpointConfiguration
        : Optional[zio.aws.apigateway.model.EndpointConfiguration.ReadOnly]
    def policy: Optional[String]
    def tags: Optional[Map[String, String]]
    def disableExecuteApiEndpoint: Optional[Boolean]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getCreatedDate: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdDate", createdDate)
    def getVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("version", version)
    def getWarnings: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("warnings", warnings)
    def getBinaryMediaTypes: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("binaryMediaTypes", binaryMediaTypes)
    def getMinimumCompressionSize: ZIO[Any, AwsError, NullableInteger] =
      AwsError.unwrapOptionField(
        "minimumCompressionSize",
        minimumCompressionSize
      )
    def getApiKeySource
        : ZIO[Any, AwsError, zio.aws.apigateway.model.ApiKeySourceType] =
      AwsError.unwrapOptionField("apiKeySource", apiKeySource)
    def getEndpointConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.apigateway.model.EndpointConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("endpointConfiguration", endpointConfiguration)
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getDisableExecuteApiEndpoint: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("disableExecuteApiEndpoint", disableExecuteApiEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ) extends zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly {
    override val id: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: String)
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val createdDate: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdDate())
      .map(value => zio.aws.apigateway.model.primitives.Timestamp(value))
    override val version: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value => value: String)
    override val warnings: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.warnings())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val binaryMediaTypes: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.binaryMediaTypes())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val minimumCompressionSize: Optional[NullableInteger] =
      zio.aws.core.internal
        .optionalFromNullable(impl.minimumCompressionSize())
        .map(value => value: NullableInteger)
    override val apiKeySource
        : Optional[zio.aws.apigateway.model.ApiKeySourceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.apiKeySource())
        .map(value => zio.aws.apigateway.model.ApiKeySourceType.wrap(value))
    override val endpointConfiguration
        : Optional[zio.aws.apigateway.model.EndpointConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.endpointConfiguration())
        .map(value =>
          zio.aws.apigateway.model.EndpointConfiguration.wrap(value)
        )
    override val policy: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value => value: String)
    override val tags: Optional[Map[String, String]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val disableExecuteApiEndpoint: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.disableExecuteApiEndpoint())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ): zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigateway_2.13-6.20.149.1-sources.jar: zio/aws/apigateway/model/CreateRestApiResponse.scala <==
package zio.aws.apigateway.model
import zio.aws.apigateway.model.primitives.{NullableInteger, Timestamp}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateRestApiResponse(
    id: Optional[String] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    createdDate: Optional[Timestamp] = Optional.Absent,
    version: Optional[String] = Optional.Absent,
    warnings: Optional[Iterable[String]] = Optional.Absent,
    binaryMediaTypes: Optional[Iterable[String]] = Optional.Absent,
    minimumCompressionSize: Optional[NullableInteger] = Optional.Absent,
    apiKeySource: Optional[zio.aws.apigateway.model.ApiKeySourceType] =
      Optional.Absent,
    endpointConfiguration: Optional[
      zio.aws.apigateway.model.EndpointConfiguration
    ] = Optional.Absent,
    policy: Optional[String] = Optional.Absent,
    tags: Optional[Map[String, String]] = Optional.Absent,
    disableExecuteApiEndpoint: Optional[Boolean] = Optional.Absent,
    rootResourceId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse = {
    import CreateRestApiResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        createdDate.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdDate)
      .optionallyWith(version.map(value => value: java.lang.String))(_.version)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.warnings)
      .optionallyWith(
        binaryMediaTypes.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.binaryMediaTypes)
      .optionallyWith(minimumCompressionSize.map(value => value: Integer))(
        _.minimumCompressionSize
      )
      .optionallyWith(apiKeySource.map(value => value.unwrap))(_.apiKeySource)
      .optionallyWith(
        endpointConfiguration.map(value => value.buildAwsValue())
      )(_.endpointConfiguration)
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(
        disableExecuteApiEndpoint.map(value => value: java.lang.Boolean)
      )(_.disableExecuteApiEndpoint)
      .optionallyWith(rootResourceId.map(value => value: java.lang.String))(
        _.rootResourceId
      )
      .build()
  }
  def asReadOnly: zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly =
    zio.aws.apigateway.model.CreateRestApiResponse.wrap(buildAwsValue())
}
object CreateRestApiResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.CreateRestApiResponse =
      zio.aws.apigateway.model.CreateRestApiResponse(
        id.map(value => value),
        name.map(value => value),
        description.map(value => value),
        createdDate.map(value => value),
        version.map(value => value),
        warnings.map(value => value),
        binaryMediaTypes.map(value => value),
        minimumCompressionSize.map(value => value),
        apiKeySource.map(value => value),
        endpointConfiguration.map(value => value.asEditable),
        policy.map(value => value),
        tags.map(value => value),
        disableExecuteApiEndpoint.map(value => value),
        rootResourceId.map(value => value)
      )
    def id: Optional[String]
    def name: Optional[String]
    def description: Optional[String]
    def createdDate: Optional[Timestamp]
    def version: Optional[String]
    def warnings: Optional[List[String]]
    def binaryMediaTypes: Optional[List[String]]
    def minimumCompressionSize: Optional[NullableInteger]
    def apiKeySource: Optional[zio.aws.apigateway.model.ApiKeySourceType]
    def endpointConfiguration
        : Optional[zio.aws.apigateway.model.EndpointConfiguration.ReadOnly]
    def policy: Optional[String]
    def tags: Optional[Map[String, String]]
    def disableExecuteApiEndpoint: Optional[Boolean]
    def rootResourceId: Optional[String]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getCreatedDate: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdDate", createdDate)
    def getVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("version", version)
    def getWarnings: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("warnings", warnings)
    def getBinaryMediaTypes: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("binaryMediaTypes", binaryMediaTypes)
    def getMinimumCompressionSize: ZIO[Any, AwsError, NullableInteger] =
      AwsError.unwrapOptionField(
        "minimumCompressionSize",
        minimumCompressionSize
      )
    def getApiKeySource
        : ZIO[Any, AwsError, zio.aws.apigateway.model.ApiKeySourceType] =
      AwsError.unwrapOptionField("apiKeySource", apiKeySource)
    def getEndpointConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.apigateway.model.EndpointConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("endpointConfiguration", endpointConfiguration)
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getDisableExecuteApiEndpoint: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("disableExecuteApiEndpoint", disableExecuteApiEndpoint)
    def getRootResourceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("rootResourceId", rootResourceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ) extends zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly {
    override val id: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: String)
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val createdDate: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdDate())
      .map(value => zio.aws.apigateway.model.primitives.Timestamp(value))
    override val version: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value => value: String)
    override val warnings: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.warnings())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val binaryMediaTypes: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.binaryMediaTypes())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val minimumCompressionSize: Optional[NullableInteger] =
      zio.aws.core.internal
        .optionalFromNullable(impl.minimumCompressionSize())
        .map(value => value: NullableInteger)
    override val apiKeySource
        : Optional[zio.aws.apigateway.model.ApiKeySourceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.apiKeySource())
        .map(value => zio.aws.apigateway.model.ApiKeySourceType.wrap(value))
    override val endpointConfiguration
        : Optional[zio.aws.apigateway.model.EndpointConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.endpointConfiguration())
        .map(value =>
          zio.aws.apigateway.model.EndpointConfiguration.wrap(value)
        )
    override val policy: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value => value: String)
    override val tags: Optional[Map[String, String]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val disableExecuteApiEndpoint: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.disableExecuteApiEndpoint())
        .map(value => value: Boolean)
    override val rootResourceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.rootResourceId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.CreateRestApiResponse
  ): zio.aws.apigateway.model.CreateRestApiResponse.ReadOnly = new Wrapper(impl)
}
